@@ -1,19 +1,10 @@
+# SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+# SPDX-FileCopyrightText: 2014 ownCloud GmbH
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
-# Copyright (C) by Klaas Freitag <freitag@owncloud.com>
-#
-# This program is the core of OwnCloud integration to Caja
-# It will be installed on /usr/share/caja-python/extensions/ with the paquet owncloud-client-caja
-# (https://github.com/owncloud/client/edit/master/shell_integration/caja/syncstate.py)
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
-# for more details.
+# This program is the core of the nextcloud integration to Caja
+# It will be installed on /usr/share/caja-python/extensions/ with the paquet Nextcloud-client-caja
+# (https://github.com/nextcloud/desktop/edit/master/shell_integration/caja/syncstate.py)
 
 import sys
 python3 = sys.version_info[0] >= 3
@@ -428,23 +419,23 @@ class SyncStateExtension_Nextcloud(GObject.GObject, Caja.InfoProvider):
             self.invalidate_items_underneath(args[0])
 
     def set_emblem(self, item, state):
-        Emblems = { 'OK'        : appname +'_ok',
-                    'SYNC'      : appname +'_sync',
-                    'NEW'       : appname +'_sync',
-                    'IGNORE'    : appname +'_warn',
-                    'ERROR'     : appname +'_error',
-                    'OK+SWM'    : appname +'_ok_shared',
-                    'SYNC+SWM'  : appname +'_sync_shared',
-                    'NEW+SWM'   : appname +'_sync_shared',
-                    'IGNORE+SWM': appname +'_warn_shared',
-                    'ERROR+SWM' : appname +'_error_shared',
+        Emblems = { 'OK'        : [appname + '_ok'],
+                    'SYNC'      : [appname + '_sync'],
+                    'NEW'       : [appname + '_sync'],
+                    'IGNORE'    : [appname + '_warn'],
+                    'ERROR'     : [appname + '_error'],
+                    'OK+SWM'    : [appname + '_a_shared', appname + '_ok'],
+                    'SYNC+SWM'  : [appname + '_a_shared', appname + '_sync'],
+                    'NEW+SWM'   : [appname + '_a_shared', appname + '_sync'],
+                    'IGNORE+SWM': [appname + '_a_shared', appname + '_warn'],
+                    'ERROR+SWM' : [appname + '_a_shared', appname + '_error'],
                     'NOP'       : ''
                   }
 
         emblem = 'NOP' # Show nothing if no emblem is defined.
         if state in Emblems:
-            emblem = Emblems[state]
-        item.add_emblem(emblem)
+            for emblem in Emblems[state]:
+                item.add_emblem(emblem)
 
     def update_file_info(self, item):
         if item.get_uri_scheme() != 'file':
